# Systems


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**console_baud_rate** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**device_group** | **str** |  | [optional] 
**gps_latitude** | **str** |  | [optional] 
**gps_longitude** | **str** |  | [optional] 
**host_name** | **str** |  | [optional] 
**location** | **str** |  | [optional] 
**on_demand_tunnel** | **str** |  | [optional] 
**on_demand_tunnel_idle_timeout** | **int** |  | [optional] 
**port_hopping** | **str** |  | [optional] 
**port_offset** | **int** |  | [optional] 
**site_id** | **str** |  | [optional] 
**system_ip** | **str** |  | [optional] 
**time_zone** | **str** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


